@@ -18,17 +18,15 @@ class RevokeAuthButton : public QPushButton
 {
     Q_OBJECT
 public:
-    RevokeAuthButton(const QString &appName, KWallet::Wallet *wallet);
-
-private Q_SLOTS:
-    void onClicked();
+    explicit RevokeAuthButton(const QString &appName, KWallet::Wallet *wallet);
 
 Q_SIGNALS:
     void appRevoked(const QString&);
 
 private:
-    QString             _appName;
-    KWallet::Wallet     *_wallet = nullptr;
+    void onClicked();
+    const QString             _appName;
+    KWallet::Wallet     *const _wallet;
 };
 
 #endif // REVOKEAUTHBUTTON_H
